@@ -1,8 +1,13 @@
 """ Package for computing dice probabilities.
 
-See [this JupyterLite distribution](https://highdiceroller.gitlab.io/icepool/notebooks/lab/index.html) for examples.
+See [this JupyterLite distribution](https://highdiceroller.github.io/icepool/notebooks/lab/index.html) for examples.
 
-[Visit the project page.](https://gitlab.com/highdiceroller/icepool)
+[Visit the project page.](https://github.com/HighDiceRoller/icepool)
+
+General conventions:
+
+* Unless explictly specified otherwise, all sorting is in ascending order.
+* The words "min" and "max" refer to outcomes, and the words "low" and "high" refer to dice in a pool.
 """
 
 __docformat__ = 'google'
@@ -24,8 +29,10 @@ lowest = icepool.die.base.BaseDie.lowest
 max_outcome = icepool.die.base.BaseDie.max_outcome
 min_outcome = icepool.die.base.BaseDie.min_outcome
 
-from icepool.pool import Pool, standard_pool, DicePool
-from icepool.eval_pool import EvalPool, WrapFuncEval, SumPool, sum_pool, FindBestSet, FindBestRun
+from icepool.pool.base import BasePool
+from icepool.pool.pool import Pool, standard_pool, DicePool
+from icepool.pool.roll import PoolRoll
+from icepool.pool.eval import EvalPool, WrapFuncEval, SumPool, sum_pool, FindBestSet, FindBestRun
 
 import enum
 
@@ -41,6 +48,8 @@ __all__ = ['Die',
     'lowest', 'highest', 'max_outcome', 'min_outcome',
     'apply', 'dice_with_common_ndim',
     'Reroll',
+    'BasePool',
     'Pool', 'standard_pool', 'DicePool',
+    # 'PoolRoll',  # Not needed externally due to implicit casts
     'EvalPool', 'WrapFuncEval', 'SumPool', 'sum_pool', 'FindBestSet', 'FindBestRun',
     'd2', 'd3', 'd4', 'd6', 'd8', 'd10', 'd12', 'd20', 'd100']
